import { Signer } from '@ethersproject/abstract-signer';
import { Provider } from '@ethersproject/abstract-provider';
import { BigintIsh } from '@uniswap/sdk-core';
/**
 * Approves an address to transfer ERC20 Tokens on behalf of a Signer
 * @param contractAddress The address that is approved to transfer Tokens on behalf of a Signer
 * @param tokenAddress The address of the ERC20 token that approves the transfer
 * @param amount The amount of the Token to be approved for transfer
 * @param signer The signer that approves the transfer on his behalf
 */
export declare function approveTokenTransfer(contractAddress: string, tokenAddress: string, amount: BigintIsh, signer: Signer): Promise<void>;
/**
 * Fetches the transfer allowance of a contract for a signer on an ERC20 token
 * @param {string} contractAddress The address that wants to transfer tokens on behalf of a signer
 * @param {string} tokenAddress The address of the ERC20 token
 * @param {string} signerAddress The address of the signer that owns the tokens
 * @param {Provider} provider An RPC provider to make the request
 * @returns {Promise<bigint>} The transfer allowance of the contract
 */
export declare function getAllowance(contractAddress: string, tokenAddress: string, signerAddress: string, provider: Provider): Promise<bigint>;
