import { Contract } from '@ethersproject/contracts';
import { ERC20_ABI } from 'src/constants';
/**
 * Approves an address to transfer ERC20 Tokens on behalf of a Signer
 * @param contractAddress The address that is approved to transfer Tokens on behalf of a Signer
 * @param tokenAddress The address of the ERC20 token that approves the transfer
 * @param amount The amount of the Token to be approved for transfer
 * @param signer The signer that approves the transfer on his behalf
 */
export async function approveTokenTransfer(contractAddress, tokenAddress, amount, signer) {
    const tokenContract = new Contract(tokenAddress, ERC20_ABI, signer);
    if (typeof amount !== "string") {
        amount = amount.toString(10);
    }
    await tokenContract["approve"](contractAddress, amount);
}
/**
 * Fetches the transfer allowance of a contract for a signer on an ERC20 token
 * @param {string} contractAddress The address that wants to transfer tokens on behalf of a signer
 * @param {string} tokenAddress The address of the ERC20 token
 * @param {string} signerAddress The address of the signer that owns the tokens
 * @param {Provider} provider An RPC provider to make the request
 * @returns {Promise<bigint>} The transfer allowance of the contract
 */
export async function getAllowance(contractAddress, tokenAddress, signerAddress, provider) {
    const tokenContract = new Contract(tokenAddress, ERC20_ABI, provider);
    const allowance = tokenContract["allowance"](signerAddress, contractAddress);
    return BigInt(allowance.toString(10));
}
//# sourceMappingURL=approveTokenTransfer.js.map